﻿using System;
using Xilium.CefGlue;
using System.Diagnostics;
using System.Windows.Forms;

namespace CefGlueScreenshot
{
    class Program
    {
        static string Filename = "screenshot.bmp";
        static string Url = "http://www.google.com";

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static int Main(string[] args)
        {
            var mainArgs = new CefMainArgs(args);
            var app = new CefSimpleApp();

            var exitCode = CefRuntime.ExecuteProcess(mainArgs, app);
            if (exitCode != -1)
                return exitCode;

            var settings = new CefSettings
            {
                SingleProcess = false,
                MultiThreadedMessageLoop = true,
                LogSeverity = CefLogSeverity.Disable,
                LogFile = "CefGlue.log",
            };

            SimpleNativeWindow window = new SimpleNativeWindow(0, 0, Screen.PrimaryScreen.WorkingArea.Width, Screen.PrimaryScreen.WorkingArea.Height);

            CefRuntime.Initialize(mainArgs, settings, app);

            CefSimpleBrowser browser = new CefSimpleBrowser(window);

            bool browserLoaded = false;

            System.Diagnostics.Stopwatch sw = new Stopwatch();

            while (true)
            {
                if (!settings.MultiThreadedMessageLoop)
                {
                    CefRuntime.DoMessageLoopWork();
                }

                //Start the browser loading process
                if (!browserLoaded && browser.GetBrowser() != null)
                {
                    browser.GetBrowser().GetMainFrame().LoadUrl(Program.Url);
                    browserLoaded = true;
                }


                if (browserLoaded)
                {
                    if (browser.GetBrowser().IsLoading)
                    {
                        sw.Restart();
                    }
                    else
                    {
                        if (sw.ElapsedMilliseconds > 1000)
                        {
                            browser.WindowBitmap.Save(Program.Filename);
                            browser.WindowBitmap.Dispose();
                            break;
                        }
                    }
                }

            }

            CefBrowserHost host = browser.GetBrowser().GetHost();
            host.CloseBrowser();
            host.ParentWindowWillClose();
            host.Dispose();

            CefRuntime.Shutdown();

            window.DestroyHandle();

            return 0;
        }
    }
}
